@@ -4,6 +4,7 @@ from __future__ import print_function, unicode_literals
 
 import time
 import os
+import re
 import shutil
 from xml.etree import cElementTree as ET
 import plistlib
@@ -21,7 +22,7 @@ import logging
 - things that need to be improved are marked with "# TO DO"
 """
 
-__version__ = "0.3.6"
+__version__ = "0.4.2"
 description = """
 UFO Normalizer (version %s):
 
@@ -158,11 +159,9 @@ else:
 class UFONormalizerError(Exception):
     pass
 
-
 DEFAULT_FLOAT_PRECISION = 10
 FLOAT_FORMAT = "%%.%df" % DEFAULT_FLOAT_PRECISION
 
-
 def normalizeUFO(ufoPath, outputPath=None, onlyModified=True,
                  floatPrecision=DEFAULT_FLOAT_PRECISION, writeModTimes=True):
     global FLOAT_FORMAT
@@ -452,6 +451,7 @@ def _normalizeDictGuideline(guideline):
     """
     - Don't write if angle is defined but either x or y are not defined.
     - Don't write if both x and y are defined but angle is not defined.
+      However <x=300 y=0> or <x=0 y=300> are allowed, and the 0 becomes None.
     """
     x = guideline.get("x")
     y = guideline.get("y")
@@ -459,15 +459,6 @@ def _normalizeDictGuideline(guideline):
     name = guideline.get("name")
     color = guideline.get("color")
     identifier = guideline.get("identifier")
-    # either x or y must be defined
-    if x is None and y is None:
-        return
-    # if angle is specified, x and y must be specified
-    if (x is None or y is None) and angle is not None:
-        return
-    # if x and y are specified, angle must be specified
-    if (x is not None and y is not None) and angle is None:
-        return
     # value errors
     if x is not None:
         try:
@@ -484,6 +475,22 @@ def _normalizeDictGuideline(guideline):
             angle = float(angle)
         except ValueError:
             return
+    # The spec was ambiguous about y=0 or x=0, so don't raise an error here,
+    # instead, <x=300 y=0> or <x=0 y=300> are allowed, and the 0 becomes None.
+    if angle is None:
+        if x == 0:
+            x = None
+        if y == 0:
+            y = None
+    # either x or y must be defined
+    if x is None and y is None:
+        return
+    # if angle is specified, x and y must be specified
+    if (x is None or y is None) and angle is not None:
+        return
+    # if x and y are specified, angle must be specified
+    if (x is not None and y is not None) and angle is None:
+        return
     normalized = {}
     if x is not None:
         normalized["x"] = x
@@ -1170,6 +1177,8 @@ class XMLWriter(object):
         self.raw(line)
 
     def text(self, text):
+        text = text.strip("\n")
+        text = dedent_tabs(text)
         text = text.strip()
         text = xmlEscapeText(text)
         paragraphs = []
@@ -1350,6 +1359,64 @@ def xmlConvertFloat(value):
 def xmlConvertInt(value):
     return str(value)
 
+
+# ---------------
+# Text Operations
+# ---------------
+
+WHITESPACE_ONLY_RE = re.compile('^[\s\t]+$', re.MULTILINE)
+LEADING_WHITESPACE_RE = re.compile('(^(?:\s{4}|\t)*)(?:[^\t\n])', re.MULTILINE)
+
+def dedent_tabs(text):
+    """
+    Based on `textwrap.dedent`, but modified to only work on tabs and 4-space indents
+
+    Remove any common leading tabs from every line in `text`.
+    This can be used to make triple-quoted strings line up with the left
+    edge of the display, while still presenting them in the source code
+    in indented form.
+
+    Entirely blank lines are normalized to a newline character.
+    """
+    # Look for the longest leading string of spaces and tabs common to
+    # all lines.
+    margin = None
+    text = WHITESPACE_ONLY_RE.sub('', text)
+    indents = LEADING_WHITESPACE_RE.findall(text)
+    for indent in indents:
+        if margin is None:
+            margin = indent
+
+        # Current line more deeply indented than previous winner:
+        # no change (previous winner is still on top).
+        elif indent.startswith(margin):
+            pass
+
+        # Current line consistent with and no deeper than previous winner:
+        # it's the new winner.
+        elif margin.startswith(indent):
+            margin = indent
+
+        # Find the largest common whitespace between current line and previous
+        # winner.
+        else:
+            for i, (x, y) in enumerate(zip(margin, indent)):
+                if x != y:
+                    margin = margin[:i]
+                    break
+
+    # sanity check (testing/debugging only)
+    if 0 and margin:
+        for line in text.split("\n"):
+            assert not line or line.startswith(margin), \
+                   "line = %r, margin = %r" % (line, margin)
+
+    if margin:
+        text = re.sub(r'(?m)^' + margin, '', text)
+    return text
+
+
+
 # ---------------
 # Path Operations
 # ---------------
@@ -1585,7 +1652,7 @@ def readImageReferences(lib):
 #
 # This was taken directly from the UFO 3 specification.
 
-illegalCharacters = "\" * + / : < > ? [ \ ] | \0".split(" ")
+illegalCharacters = '" * + / : < > ? [ \\ ] | \0'.split(" ")
 illegalCharacters += [chr(i) for i in range(1, 32)]
 illegalCharacters += [chr(0x7F)]
 reservedFileNames = "CON PRN AUX CLOCK$ NUL A:-Z: COM1".lower().split(" ")
