@@ -747,6 +747,20 @@ class UFONormalizerTest(unittest.TestCase):
         _normalizeGlifGuideline(element, writer)
         self.assertEqual(writer.getText(), '')
 
+    def test_normalizeFontInfoPlist_guidelines_vertical_y_is_zero(self):
+        # Actually a vertical guide
+        element = ET.fromstring("<guideline x='100' y='0'/>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifGuideline(element, writer)
+        self.assertEqual(writer.getText(), '<guideline x="100"/>')
+
+    def test_normalizeFontInfoPlist_guidelines_horizontal_x_is_zero(self):
+        # Actually an horizontal guide
+        element = ET.fromstring("<guideline x='0.0' y='100'/>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifGuideline(element, writer)
+        self.assertEqual(writer.getText(), '<guideline y="100"/>')
+
     def test_normalizeGLIF_lib_defined(self):
         e = '''
         <lib>
@@ -822,6 +836,53 @@ class UFONormalizerTest(unittest.TestCase):
             writer.getText(),
             "<note>\n\tLine1\n\t\n\t    Line3\n</note>")
 
+        # Normalizer should not indent Line2 and Line3 more than already indented
+        element = ET.fromstring(
+            "<note>\n\tLine1\n\tLine2\n\tLine3\n</note>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifNote(element, writer)
+        self.assertEqual(
+            writer.getText(),
+            "<note>\n\tLine1\n\tLine2\n\tLine3\n</note>")
+
+        # Normalizer should keep the extra tab in line 2
+        element = ET.fromstring(
+            "<note>\n\tLine1\n\t\tLine2\n\tLine3\n</note>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifNote(element, writer)
+        self.assertEqual(
+            writer.getText(),
+            "<note>\n\tLine1\n\t\tLine2\n\tLine3\n</note>")
+
+        # Normalizer should keep the extra spaces on line 2
+        element = ET.fromstring(
+            "<note>\n\tLine1\n\t    Line2\n\tLine3\n</note>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifNote(element, writer)
+        self.assertEqual(
+            writer.getText(),
+            "<note>\n\tLine1\n\t    Line2\n\tLine3\n</note>")
+
+        # Normalizer should remove the extra tab all lines have in common,
+        # but leave the additional tab on line 2
+        element = ET.fromstring(
+            "<note>\n\t\tLine1\n\t\t\tLine2\n\t\tLine3\n</note>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifNote(element, writer)
+        self.assertEqual(
+            writer.getText(),
+            "<note>\n\tLine1\n\t\tLine2\n\tLine3\n</note>")
+
+        # Normalizer should remove the extra 4-space all lines have in common,
+        # but leave the additional 4-space on line 2
+        element = ET.fromstring(
+            "<note>\n        Line1\n            Line2\n        Line3\n</note>")
+        writer = XMLWriter(declaration=None)
+        _normalizeGlifNote(element, writer)
+        self.assertEqual(
+            writer.getText(),
+            "<note>\n\tLine1\n\t    Line2\n\tLine3\n</note>")
+
     def test_normalizeGLIF_note_undefined(self):
         element = ET.fromstring("<note></note>")
         writer = XMLWriter(declaration=None)
